#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.interfaces import WEBMASTER_ROLE
from pyams_notify.interfaces import INotification, INotificationHandler
from pyams_security.interfaces import IAuthenticatedPrincipalEvent, IProtectedObject, ADMIN_USER_ID, SYSTEM_ADMIN_ROLE

# import packages
from pyams_notify.event import Notification
from pyams_utils.adapter import adapter_config, ContextAdapter
from pyams_utils.request import query_request
from pyramid.events import subscriber

from pyams_notify import _


#
# User authentication notification
#

@subscriber(IAuthenticatedPrincipalEvent)
def handle_authenticated_principal(event):
    """Handle authenticated principal"""
    request = query_request()
    if request is None:
        return
    translate = request.localizer.translate
    notification = Notification(request=request,
                                action='notify',
                                category='user.login',
                                source=event.principal_id,
                                message=translate(_("logged in...")))
    notification.send()


@adapter_config(name='user.login', context=INotification, provides=INotificationHandler)
class UserLoginNotificationHandler(ContextAdapter):
    """User login notification handler"""

    def get_target(self):
        root = self.context.request.root
        protection = IProtectedObject(root)
        principals = {ADMIN_USER_ID} | \
                     protection.get_principals(SYSTEM_ADMIN_ROLE) | \
                     protection.get_principals(WEBMASTER_ROLE)
        return {'principals': tuple(principals)}
